@@ -133,9 +133,10 @@ def optimize(dsk, keys, fuse_keys=None, rename_fused_keys=None, **kwargs):
     """ Optimize a dask from a dask Bag. """
     dsk = ensure_dict(dsk)
     dsk2, dependencies = cull(dsk, keys)
-    dsk3, dependencies = fuse(
-        dsk2, keys + (fuse_keys or []), dependencies, rename_keys=rename_fused_keys
-    )
+    kwargs = {}
+    if rename_fused_keys is not None:
+        kwargs["rename_keys"] = rename_fused_keys
+    dsk3, dependencies = fuse(dsk2, keys + (fuse_keys or []), dependencies, **kwargs)
     dsk4 = inline_singleton_lists(dsk3, keys, dependencies)
     dsk5 = lazify(dsk4)
     return dsk5
