@@ -4,6 +4,7 @@ import pandas as pd
 import pytest
 
 from dask.dataframe.utils import assert_eq, PANDAS_VERSION
+from dask.dataframe._compat import PANDAS_GT_0240
 import dask.dataframe as dd
 
 
@@ -45,6 +46,18 @@ def test_series_resample(obj, method, npartitions, freq, closed, label):
     assert expected.index[-1] == divisions[-1]
 
 
+@pytest.mark.parametrize("method", ["count", "nunique", "size", "sum"])
+def test_resample_has_correct_fill_value(method):
+    index = pd.date_range("2000-01-01", "2000-02-15", freq="h")
+    index = index.union(pd.date_range("4-15-2000", "5-15-2000", freq="h"))
+    ps = pd.Series(range(len(index)), index=index)
+    ds = dd.from_pandas(ps, npartitions=2)
+
+    assert_eq(
+        getattr(ds.resample("30min"), method)(), getattr(ps.resample("30min"), method)()
+    )
+
+
 def test_resample_agg():
     index = pd.date_range("2000-01-01", "2000-02-15", freq="h")
     ps = pd.Series(range(len(index)), index=index)
@@ -103,6 +116,22 @@ def test_resample_index_name():
     assert ddf.resample("D").mean().head().index.name == "date"
 
 
+@pytest.mark.skipif(not PANDAS_GT_0240, reason="nonexistent not in 0.23 or older")
+def test_series_resample_non_existent_datetime():
+    index = [
+        pd.Timestamp("2016-10-15 00:00:00"),
+        pd.Timestamp("2016-10-16 10:00:00"),
+        pd.Timestamp("2016-10-17 00:00:00"),
+    ]
+    df = pd.DataFrame([[1], [2], [3]], index=index)
+    df.index = df.index.tz_localize("America/Sao_Paulo")
+    ddf = dd.from_pandas(df, npartitions=1)
+    result = ddf.resample("1D").mean()
+    expected = df.resample("1D").mean()
+
+    assert_eq(result, expected)
+
+
 @pytest.mark.skipif(PANDAS_VERSION <= "0.23.4", reason="quantile not in 0.23")
 @pytest.mark.parametrize("agg", ["nunique", "mean", "count", "size", "quantile"])
 def test_common_aggs(agg):
